<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
  xmlns:java="http://xml.apache.org/xalan/java" xmlns:util="ExternalRef" extension-element-prefixes="util">

  <xsl:template match="CrossRef">
    <xsl:variable name="ref" select="@ref"/>
    <xsl:if test="@external">	    	
	    <xsl:variable name="external" select="@external"/>
	    <xsl:value-of select="util:getRef($external, @lang, @target, $ref)"/>
	  </xsl:if>
    
  	<fo:basic-link color="blue" internal-destination="{@target}_{@ref}">
  		<xsl:choose>
  		<xsl:when test="@target='Figure'"><xsl:apply-templates select="//Figure[@id=$ref]" mode="ref"/></xsl:when>
  		<xsl:when test="@target='Table'"><xsl:apply-templates select="//Table[@id=$ref]" mode="ref"/></xsl:when>
  		<xsl:when test="@target='Chapter'"><xsl:apply-templates select="//Chapter[@id=$ref]" mode="ref"/></xsl:when>
  		<xsl:when test="@target='Section'"><xsl:apply-templates select="//Section[@id=$ref]" mode="ref"/></xsl:when> 		
  		<xsl:when test="@target='Subsection'"><xsl:apply-templates select="//Subsection[@id=$ref]" mode="ref"/></xsl:when>
  		</xsl:choose>
  	</fo:basic-link>
  </xsl:template>
  
  <xsl:template match="FootnoteList">  
  <xsl:for-each select="Footnote">
    <a name="fn{@id}"/><a href="#fnref{@id}">[<xsl:value-of select="@id"/>]</a>
    <xsl:apply-templates/>
    <br/>
  </xsl:for-each>
  </xsl:template>
  <xsl:template match="FootnoteRef"><a name="fnref{@id}"/><a href="#fn{@id}">[<xsl:value-of select="@id"/>]</a></xsl:template>
  
  <xsl:template match="Figure" mode="ref">
  	<xsl:variable name="temp_total_figs"><xsl:number count="Figure" level="any"/></xsl:variable>       
	<xsl:variable name="temp_num_of_sub_figs">
	<xsl:number count="Figure[Title/SubTitle and substring(translate(@id, '_0123456789', '99999999999'), string-length(@id)-1, string-length(@id))='99']" level="any"/>
   	</xsl:variable>	  	
  	<xsl:variable name="no"><xsl:value-of select="$temp_total_figs - $temp_num_of_sub_figs"/></xsl:variable>
  	<xsl:variable name="subtitle">
  	<xsl:if test="Title/SubTitle"><xsl:value-of select="substring-before(substring-after(Title/SubTitle, '('), ')')"/></xsl:if>
  	</xsl:variable>
  	<xsl:value-of select="concat($no, $subtitle)"/>
  </xsl:template>  
  
  <xsl:template match="Table" mode="ref"><xsl:number level="any"/></xsl:template>
  
  <xsl:template match="Chapter" mode="ref"><xsl:number level="any"/></xsl:template>
  
  <xsl:template match="Section" mode="ref"><xsl:number count="//Chapter|//Chapter//Section" format="1.1" level="multiple"/></xsl:template>  
  
  <xsl:template match="Subsection" mode="ref"><xsl:number level="multiple" format="1.1.1" count="//Chapter|//Chapter//Section|//Chapter//Section//Subsection"/></xsl:template>
  </xsl:stylesheet>
